@@ -32,8 +32,7 @@
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
-    html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
-    html_root_url = "https://docs.rs/sha-crypt/0.3.2"
+    html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg"
 )]
 #![deny(unsafe_code)]
 #![warn(missing_docs, rust_2018_idioms)]
@@ -57,7 +56,6 @@ pub use crate::{
 };
 
 use alloc::{string::String, vec::Vec};
-use core::convert::TryInto;
 use sha2::{Digest, Sha512};
 
 #[cfg(feature = "simple")]
